@@ -277,8 +277,8 @@ class SmartWeather:
                     "icon": row["icon"],
                     "sunrise": datetime.fromtimestamp(row["sunrise"]),
                     "sunset": datetime.fromtimestamp(row["sunset"]),
-                    "air_temp_high": await cnv.temperature(row["air_temp_high"], UNIT_TEMP_CELCIUS, self._to_units_temp),
-                    "air_temp_low": await cnv.temperature(row["air_temp_low"], UNIT_TEMP_CELCIUS, self._to_units_temp),
+                    "air_temp_high": row["air_temp_high"],
+                    "air_temp_low": row["air_temp_low"],
                     "air_temp_high_color": row["air_temp_high_color"],
                     "air_temp_low_color": row["air_temp_low_color"],
                     "precip": await cnv.precip(precip, UNIT_PRECIP_MM, self._to_units_precip),
@@ -298,7 +298,7 @@ class SmartWeather:
                     "timestamp": datetime.fromtimestamp(row["time"]),
                     "conditions": row["conditions"],
                     "icon": row["icon"],
-                    "air_temperature": await cnv.temperature(row["air_temperature"], UNIT_TEMP_CELCIUS, self._to_units_temp),
+                    "air_temperature": row["air_temperature"],
                     "sea_level_pressure": await cnv.pressure(row["sea_level_pressure"], UNIT_PRESSURE_MB, self._to_units_pressure),
                     "relative_humidity": row["relative_humidity"],
                     "precip": await cnv.precip(row["precip"], UNIT_PRECIP_MM, self._to_units_precip),
@@ -313,7 +313,7 @@ class SmartWeather:
                     "wind_direction_cardinal": row["wind_direction_cardinal"],
                     "wind_direction_icon": row["wind_direction_icon"],
                     "uv": row["uv"],
-                    "feels_like": await cnv.temperature(row["feels_like"], UNIT_TEMP_CELCIUS, self._to_units_temp),
+                    "feels_like": row["feels_like"],
                     "current_condition": current_condition,
                     "current_icon": current_icon,
                 }
