@@ -1,6 +1,6 @@
 """Constant Definitions for SmartWeather."""
 
-BASE_URL = "https://swd.weatherflow.com/swd/rest/observations"
+BASE_URL = "https://swd.weatherflow.com/swd/rest"
 
 DEFAULT_TIMEOUT = 10
 
@@ -24,3 +24,11 @@ UNIT_WIND_KMH = "kmh"
 UNIT_WIND_MPH = "mph"
 UNIT_DISTANCE_KM = "km"
 UNIT_DISTANCE_MI = "mi"
+
+FORECAST_TYPE_DAILY = "daily"
+FORECAST_TYPE_HOURLY = "hourly"
+
+FORECAST_TYPES = [
+    FORECAST_TYPE_DAILY,
+    FORECAST_TYPE_HOURLY,
+]
